#!/usr/bin/python
# -*- coding: utf-8 -*-

"""audioidmon_extract_fingerprint: Script extracts an audio fingerprint from an audio file."""

__author__  = 'Lars Fabig'
__date__    = '09.08.2016'
__email__   = 'lfabig@mufin.com'
__docformat__ = 'reStructuredText'


# Standard library imports ...
import argparse
import pkg_resources
import sys

# Local imports ...
import audioidmon
import audioidmon.utils


# Init command line parser
parser = argparse.ArgumentParser(prog='audioidmon_extract_fingerprint', description='Extract a fingerprint from an audio file.')
parser.add_argument('host_address', help='host address of audioid monitor service, e.g. http://127.0.0.1 [string]')
parser.add_argument('audio_filename', help='name of audio file [string]')
parser.add_argument('fingerprint_filename', help='name of audio fingerprint [string]')
parser.add_argument('-v', '--verbose', help='increase output verbosity', action='store_true')
parser.add_argument('--version', help='print version number', action='version', version='%(prog)s {}'.format(pkg_resources.get_distribution('pyaudioidmon').version))


def main():
    # parsing command line options
    args = parser.parse_args()
    if not audioidmon.utils.validate_url(args.host_address):
        parser.error("invalid host url '{}'".format(args.host_address))
    # print input parameter
    if args.verbose:
        print "Extract fingerprint from audio file:"
        print "  Audio filename               : '%s'" % args.audio_filename
        print "  Fingerprint filename         : '%s'" % args.fingerprint_filename
        print "  Host address                 : '%s'" % args.host_address
    try:
        # instantiate audioid monitor client
        if args.verbose:
            print "  Init audioid fingerprint extractor ..."
        extractor = audioidmon.AudioidMonExtractorService(args.host_address)
        # extract fingerprint
        if args.verbose:
            print "  Extract fingerprint ..."
        extractor.extract_fingerprint(args.audio_filename, args.fingerprint_filename)
    except Exception as err:
        sys.stderr.write("[Error] {} : {}\n".format(type(err).__name__, str(err)))
        sys.exit(1)
    if args.verbose:
        print "Done."
    sys.exit(0)


if __name__ == '__main__':
    main()
